@@ -10,7 +10,8 @@ use Scalar::Util qw( blessed reftype );
 use Sub::Install qw( install_sub );
 
 our @EXPORT_OK = qw( build_attr_from catch_class exception has_exception
-                     inflate_message is_class_loaded is_one_of_us throw
+                     inflate_message interpolate_msg is_class_loaded
+                     is_one_of_us throw
                      throw_on_error );
 
 my $Exception_Class = 'Unexpected'; my $Should_Quote = 1;
@@ -39,15 +40,15 @@ my $_exception_class = sub {
 };
 
 my $_match_class = sub {
-   my ($x, $ref, $blessed, $does, $key) = @_;
+   my ($e, $ref, $blessed, $does, $key) = @_;
 
-   return !defined $key                                       ? !defined $x
-        : $key eq '*'                                         ? 1
-        : $key eq ':str'                                      ? !$ref
-        : $key eq $ref                                        ? 1
-        : $blessed && $x->can( 'class' ) && $x->class eq $key ? 1
-        : $blessed && $x->$does( $key )                       ? 1
-                                                              : 0;
+   return !defined $key                        ? !defined $e
+        : $key eq '*'                          ? 1
+        : $key eq ':str'                       ? !$ref
+        : $key eq $ref                         ? 1
+        : $blessed && $e->can( 'instance_of' ) ? $e->instance_of( $key )
+        : $blessed && $e->$does( $key )        ? 1
+                                               : 0;
 };
 
 my $_quote_maybe = sub {
@@ -58,14 +59,14 @@ my $_gen_checker = sub {
    my @prototable = @_;
 
    return sub {
-      my $x       = shift;
-      my $ref     = ref $x;
-      my $blessed = blessed $x;
-      my $does    = ($blessed && $x->can( 'DOES' )) || 'isa';
+      my $e       = shift;
+      my $ref     = ref $e;
+      my $blessed = blessed $e;
+      my $does    = ($blessed && $e->can( 'DOES' )) || 'isa';
       my @table   = @prototable;
 
       while (my ($key, $value) = splice @table, 0, 2) {
-         $_match_class->( $x, $ref, $blessed, $does, $key ) and return $value
+         $_match_class->( $e, $ref, $blessed, $does, $key ) and return $value
       }
 
       return;
@@ -73,9 +74,11 @@ my $_gen_checker = sub {
 };
 
 my $_inflate_placeholders = sub { # Sub visible strings for null and undef
-   return map { $_quote_maybe->( (length) ? $_ : '[]' ) }
-          map { $_ // '[?]' } @_,
-          map {       '[?]' } 0 .. 9;
+   my $defaults = shift;
+
+   return map { $_quote_maybe->( (length) ? $_ : $defaults->[ 1 ] ) }
+          map { $_ // $defaults->[ 0 ] } @_,
+          map {       $defaults->[ 0 ] } 0 .. 9;
 };
 
 # Package methods
@@ -85,15 +88,13 @@ sub import {
    my $ex_class    = delete $global_opts->{exception_class};
    # uncoverable condition false
    my $target      = $global_opts->{into} ||= caller;
-   my $ex_subr     = $target->can( 'EXCEPTION_CLASS' );
    my @want        = @_;
    my @args        = ();
 
-   $ex_subr and $ex_class = $ex_subr->();
+   $ex_class or $ex_class = $_exception_class->( $target );
 
    for my $sym (@want) {
-      if ($ex_class and $ex_class->can( 'is_exception' )
-                    and $ex_class->is_exception( $sym )) {
+      if ($ex_class->can( 'is_exception' ) and $ex_class->is_exception( $sym )){
          my $code = sub { sub { $sym } };
 
          install_sub { as => $sym, code => $code, into => $target, };
@@ -143,9 +144,22 @@ sub has_exception ($;@) {
 }
 
 sub inflate_message ($;@) { # Expand positional parameters of the form [_<n>]
-   my $msg = shift; my @args = $_inflate_placeholders->( @_ );
+   return interpolate_msg( { defaults => [ '[?]', '[]' ] }, @_ );
+}
 
-   $msg =~ s{ \[ _ (\d+) \] }{$args[ $1 - 1 ]}gmx; return $msg;
+sub interpolate_msg ($;@) {
+   my ($car, @cdr) = @_; my $msg = $car; my $opts = {};
+
+   if (ref $car eq 'HASH') {
+      $opts = $car;
+      $msg  = $opts->{message} ? $opts->{message} : shift @cdr;
+      $opts->{args} and push @cdr, @{ $opts->{args} };
+   }
+
+   my $defaults = $opts->{defaults} // [ 'undef', 'null' ];
+   my @vals     = $_inflate_placeholders->( $defaults, @cdr );
+
+   $msg =~ s{ \[ _ (\d+) \] }{$vals[ $1 - 1 ]}gmx; return $msg;
 }
 
 sub is_class_loaded ($) { # Lifted from Class::Load
@@ -300,10 +314,35 @@ the L<Unexpected::TraitFor::ExceptionClasses> role
 
 =head2 inflate_message
 
-   $message = inflate_message( $template, $arg1, $arg2, ... );
+   $message = inflate_message $template, $val1, $val2, ...;
 
 Substitute the placeholders in the C<$template> string (e.g. [_1])
-with the corresponding argument
+with the corresponding value
+
+=head2 interpolate_msg
+
+   $message = interpolate_msg $options, $template, $val1, $val2, ...;
+
+Like inflate message but you can supply an optional hash of options. Option
+hash keys are;
+
+=over 3
+
+=item C<args>
+
+An array reference of placeholder values. Use this in place of the list of
+values
+
+=item C<defaults>
+
+A reference to an array containing the default substitution values for an
+undefined value and a zero length value respectively
+
+=item C<messsage>
+
+The message template
+
+=back
 
 =head2 is_class_loaded
 
